@@ -1,3 +1,4 @@
+require 'base64'
 require 'fog/core'
 require 'fog/xml'
 require 'fog/json'
@@ -226,12 +227,14 @@ module Fog
         'ap-south-1',
         'ap-southeast-1', 'ap-southeast-2', 'ap-southeast-3', 'ap-southeast-4',
         'ca-central-1',
+        'ca-west-1',
         'cn-north-1',
         'cn-northwest-1',
         'eu-central-1',
         'eu-north-1',
         'eu-west-1', 'eu-west-2', 'eu-west-3', 'eu-south-1', 'eu-south-2',
-        'me-south-1',
+        'il-central-1',
+        'me-south-1', 'me-central-1',
         'us-east-1', 'us-east-2',
         'us-west-1', 'us-west-2',
         'sa-east-1',
