@@ -1,6 +1,6 @@
 module Fog
-  module Compute
-    class AWS
+  module AWS
+    class Compute
       class Real
         require 'fog/aws/parsers/compute/spot_datafeed_subscription'
 
@@ -30,7 +30,7 @@ module Fog
             'Bucket'    => bucket,
             'Prefix'    => prefix,
             :idempotent => true,
-            :parser     => Fog::Parsers::Compute::AWS::SpotDatafeedSubscription.new
+            :parser     => Fog::Parsers::AWS::Compute::SpotDatafeedSubscription.new
           )
         end
       end
