@@ -1,6 +1,6 @@
 module Fog
-  module Compute
-    class AWS
+  module AWS
+    class Compute
       class Real
         require 'fog/aws/parsers/compute/basic'
 
@@ -21,7 +21,7 @@ module Fog
             'Action'      => 'DeleteSnapshot',
             'SnapshotId'  => snapshot_id,
             :idempotent   => true,
-            :parser       => Fog::Parsers::Compute::AWS::Basic.new
+            :parser       => Fog::Parsers::AWS::Compute::Basic.new
           )
         end
       end
@@ -37,7 +37,7 @@ module Fog
             }
             response
           else
-            raise Fog::Compute::AWS::NotFound.new("The snapshot '#{snapshot_id}' does not exist.")
+            raise Fog::AWS::Compute::NotFound.new("The snapshot '#{snapshot_id}' does not exist.")
           end
         end
       end
