@@ -1,6 +1,6 @@
 module Fog
-  module Compute
-    class AWS
+  module AWS
+    class Compute
       class Real
         require 'fog/aws/parsers/compute/describe_placement_groups'
 
@@ -24,7 +24,7 @@ module Fog
           request({
             'Action'    => 'DescribePlacementGroups',
             :idempotent => true,
-            :parser     => Fog::Parsers::Compute::AWS::DescribePlacementGroups.new
+            :parser     => Fog::Parsers::AWS::Compute::DescribePlacementGroups.new
           }.merge!(params))
         end
       end
