@@ -1,6 +1,6 @@
 module Fog
-  module Compute
-    class AWS
+  module AWS
+    class Compute
       class Real
         require 'fog/aws/parsers/compute/describe_reserved_instances'
 
@@ -40,7 +40,7 @@ module Fog
           request({
             'Action'    => 'DescribeReservedInstances',
             :idempotent => true,
-            :parser     => Fog::Parsers::Compute::AWS::DescribeReservedInstances.new
+            :parser     => Fog::Parsers::AWS::Compute::DescribeReservedInstances.new
           }.merge!(params))
         end
       end
