@@ -1,8 +1,8 @@
 module Shindo
   class Tests
-    def succeeds
+    def succeeds(&block)
       test('succeeds') do
-        !instance_eval(&Proc.new).nil?
+        !instance_eval(&Proc.new(&block)).nil?
       end
     end
   end
